@@ -6,7 +6,7 @@ from ipaddress import IPv4Address, IPv6Address
 
 from pydantic import Field
 
-from ...base import ResponseWithMeta, BaseResponse, BaseData
+from ...base import ResponseWithMeta, BaseResponse, BaseData, BaseDelete
 
 
 class OSNames(str, Enum):
@@ -88,7 +88,7 @@ class NetworkIPs(BaseData):
     '''Список IP-адресов сети.'''
     type: NetworkIPsType = Field(..., description='Тип IP-адреса сети')
     ip: IPv4Address | IPv6Address = Field(..., description='IP-адрес')
-    ptr: str = Field(..., description='Запись имени узла')
+    ptr: str | None = Field(None, description='Запись имени узла')
     is_main: bool = Field(..., description='Сеть основная?')
 
 
@@ -159,3 +159,8 @@ class VDSArray(ResponseWithMeta):
 class VDSResponse(BaseResponse):
     '''Ответ с сервером'''
     server: VDS = Field(..., description='Облачный сервер')
+
+
+class VDSDelete(BaseResponse):
+    '''Ответ с хэшом для подтверждения удаления облачного сервера.'''
+    server_delete: BaseDelete
